module RabbitMQ::Definition
  class Create < Command
    def initialize(client, verbose, vhosts)
      super(client, verbose)
      @vhosts = (vhosts || []).compact
      if @vhosts.empty?
        @vhosts = ask("-> What vhosts do you want to create? (comma separated list)".yellow, lambda { |str| str.split(/,\s*/) })
      end
    end

    def execute
      if FileDefinition.exists?
        Logger.error "Definition file already exists in #{FileDefinition.file_path}"
      else
        @vhosts.each do |vhost|
          Logger.progress "Creating vhost '#{vhost}'" if verbose
          client.create_vhost(vhost)
          Logger.progress "Adding permissions for '#{user}' to vhost '#{vhost}'" if verbose
          add_permissions_for_vhost(vhost)
        end
        Dump.run(client, false, @vhosts)
      end
    end
  end
end
