module RabbitMQ::Definition
  class Drop < Command
    def execute
      if !FileDefinition.exists?
        Logger.error "No definition with vhosts exists"
      else
        if !agree("This will delete vhosts (#{vhost_names.join(',')}), continue? y/n".yellow)
          Logger.error "Aborted by user"
        else
          delete_vhosts
          Logger.progress "Removing definition..."
          definition.destroy
          Logger.success "Done"
        end
      end
    end

    private

    def definition
      @definition ||= FileDefinition.read
    end

    def vhost_names
      @vhost_names ||= definition.vhosts.map { |vhost| vhost['name'] }
    end

    def delete_vhosts
      vhost_names.each do |vhost|
        Logger.progress "Deleting vhost '#{vhost}'..." if verbose
        client.delete_vhost(vhost)
      end
    end

  end
end
