module RabbitMQ::Definition
  class Dump < Command
    def initialize(client, verbose, vhosts = nil)
      super(client, verbose)
      @vhosts = vhosts || FileDefinition.read.vhosts.map { |vhost| vhost['name'] }
    end

    def execute
      FileDefinition.new(filter_and_order_list_definition).tap do |definition|
        Logger.info definition.to_json if verbose
        Logger.progress "Saving definition..."
        definition.save
        Logger.success "Done"
      end
    end

    private

    def filter_and_order_list_definition
      client.list_definitions.reduce({}) do |result, (key, value)|
        value = case key
        when "vhosts"
          @vhosts.sort.map {|name| {'name' => name} }
        when "queues", "exchanges"
          filter_vhosts(value).sort do |a, b|
            [a["vhost"], a["name"]] <=> [b["vhost"], b["name"]]
          end
        when "bindings"
          filter_vhosts(value).sort do |a, b|
            [a["vhost"], a["source"], a["destination"], a["routing_key"]] <=> [b["vhost"], b["source"], b["destination"], b["routing_key"]]
          end
        else
          value
        end
        result[key] = value
        result
      end
    end

    def filter_vhosts(items)
      items.reduce([]) do |array, item|
        array.push(item) if @vhosts.include?(item["vhost"])
        array
      end
    end

  end
end
